@@ -1,6 +1,7 @@
-# last modified 2020-04-22 by J. Fox
+# last modified 2022-01-10 by J. Fox
 
-polychor <- function (x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.9999, start){
+polychor <- function (x, y, ML=FALSE, control=list(), std.err=FALSE, 
+                      maxcor=.9999, start, thresholds=FALSE){
         f <- function(pars) {
             if (length(pars) == 1){
                 rho <- pars
@@ -86,6 +87,18 @@ polychor <- function (x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.999
                                ML=TRUE)
                 class(result) <- "polycor"
                 return(result)
+            } else if (thresholds){
+                    result <- list(type="polychoric",
+                                   rho=result$par[1],
+                                   row.cuts=result$par[2:r],
+                                   col.cuts=result$par[(r+1):(r+c-1)],
+                                   var=NA,
+                                   n=n,
+                                   chisq=NA,
+                                   df=NA,
+                                   ML=TRUE)
+                    class(result) <- "polycor"
+                    return(result)
             }
             else return(as.vector(result$par[1]))
         }
@@ -104,6 +117,8 @@ polychor <- function (x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.999
             df <- length(tab) - r - c 
             result <- list(type="polychoric",
                            rho=result$par,
+                           row.cuts=rc,
+                           col.cuts=cc,
                            var=1/result$hessian,
                            n=n,
                            chisq=chisq,
@@ -111,6 +126,22 @@ polychor <- function (x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.999
                            ML=FALSE)
             class(result) <- "polycor"
             return(result)
+        } else {
+                rho <- optimise(f, interval=c(-maxcor, maxcor))$minimum
+                if (thresholds){
+                        result <- list(type="polychoric",
+                                       rho=rho,
+                                       row.cuts=rc,
+                                       col.cuts=cc,
+                                       var=NA,
+                                       n=n,
+                                       chisq=NA,
+                                       df=NA,
+                                       ML=FALSE)
+                        class(result) <- "polycor"
+                        return(result) 
+                } else {
+                        return(rho)
+                }
         }
-        else optimise(f, interval=c(-maxcor, maxcor))$minimum
-    }
+}
